-----------------------------------------------------------------------------------------------
-- Client Lua Script for InviteHelper
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Window"
 
-----------------------------------------------------------------------------------------------
-- InviteHelper Module Definition
-----------------------------------------------------------------------------------------------
local InviteHelper = {} 
local inviteActive = false
 
-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
-- e.g. local kiExampleVariableMax = 999
 
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function InviteHelper:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    -- initialize variables here

    return o
end

function InviteHelper:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {
		-- "UnitOrPackageName",
	}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end
 

-----------------------------------------------------------------------------------------------
-- InviteHelper OnLoad
-----------------------------------------------------------------------------------------------
function InviteHelper:OnLoad()
    -- load our form file
	self.xmlDoc = XmlDoc.CreateFromFile("InviteHelper.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
end

-----------------------------------------------------------------------------------------------
-- InviteHelper OnDocLoaded
-----------------------------------------------------------------------------------------------
function InviteHelper:OnDocLoaded()

	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then
	    self.wndMain = Apollo.LoadForm(self.xmlDoc, "InviteHelperForm", nil, self)
		if self.wndMain == nil then
			Apollo.AddAddonErrorText(self, "Could not load the main window for some reason.")
			return
		end
		
	    self.wndMain:Show(false, true)

		-- if the xmlDoc is no longer needed, you should set it to nil
		-- self.xmlDoc = nil
		
		-- Register handlers for events, slash commands and timer, etc.
		-- e.g. Apollo.RegisterEventHandler("KeyDown", "OnKeyDown", self)
		Apollo.RegisterSlashCommand("invh", "OnInviteHelperOn", self)
		Apollo.RegisterEventHandler("Group_Updated", "GroupUpdate", self)

		-- Do additional Addon initialization here
	end
end

-----------------------------------------------------------------------------------------------
-- InviteHelper Functions
-----------------------------------------------------------------------------------------------
-- Define general functions here

-- on SlashCommand "/invh"
function InviteHelper:OnInviteHelperOn()
	self.wndMain:Invoke() -- show the window
	inviteActive = true
end

function InviteHelper:GroupUpdate()
	if not GroupLib.InRaid() and inviteActive then
		GroupLib.ConvertToRaid()
		self:StartInvite()
	end
end

function contains (list,item) 
	for _,v in pairs(list) do 
	
		if item  == v then 
			return true 
		end 
	end 
	return false 
end
	




function InviteHelper:GetList()
	local text = self.wndMain:FindChild("InviteText"):GetText()
	local roles = {"TANK","TANKS","HEAL", "HEALER","HEALERS", "DPS","DDS", "DAMAGE"}
	local list = {}
	local invList = {}
	local function trim(s) return (s:gsub("^%s*(.-)%s*$", "%1")) end
	local function helper(line) table.insert(list , line) return "" end
	
	helper((text:gsub("(.-)\r?\n", helper)))
		
	for _,v in pairs(list) do
		if (#trim(v) > 0 and not contains(roles, string.upper(trim(v)))) then
			table.insert(invList,trim(v))
		end
	end

	

	return invList
end

function InviteHelper:StartInvite()
	local list =	self:GetList()
	
	for _,player in pairs(list) do
		ChatSystemLib.Command(("/%s %s"):format("invite", player))
		--Print(player)
	end
end


-----------------------------------------------------------------------------------------------
-- InviteHelperForm Functions
-----------------------------------------------------------------------------------------------
-- when the OK button is clicked
function InviteHelper:OnOK()
	self:StartInvite()
end

-- when the Cancel button is clicked
function InviteHelper:OnCancel()
	self.wndMain:Close() -- hide the window
	inviteActive = false
end


-----------------------------------------------------------------------------------------------
-- InviteHelper Instance
-----------------------------------------------------------------------------------------------
local InviteHelperInst = InviteHelper:new()
InviteHelperInst:Init()
